<?php
/** Lingua Franca Nova (Lingua Franca Nova)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cgboeree
 * @author Malafaya
 * @author Reedy
 * @author Urhixidur
 */

$namespaceNames = array(
	NS_SPECIAL          => 'Spesial',
	NS_TALK             => 'Discute',
	NS_USER             => 'Usor',
	NS_USER_TALK        => 'Usor_Discute',
	NS_PROJECT_TALK     => '$1_Discute',
	NS_FILE             => 'Fix',
	NS_FILE_TALK        => 'Fix_Discute',
	NS_TEMPLATE         => 'Model',
	NS_TEMPLATE_TALK    => 'Model_Discute',
	NS_HELP             => 'Aida',
	NS_HELP_TALK        => 'Aida_Discute',
	NS_CATEGORY         => 'Categoria',
	NS_CATEGORY_TALK    => 'Categoria_Discute',
);

$specialPageAliases = array(
	'Newimages'                 => array( 'FixesNova' ),
	'Newpages'                  => array( 'PajesNova' ),
);

$messages = array(
# User preference toggles
'tog-underline'               => 'Sulinia lias:',
'tog-highlightbroken'         => 'Forma lias rompeda <a href="" class="new">como esta</a> (alterna: como esta <a href="" class="internal">?</a>).',
'tog-justify'                 => 'Ajusta paragrafes',
'tog-hideminor'               => 'Asconda editas minor en cambias resente',
'tog-extendwatchlist'         => 'Grandi la lista oservada per mostra tota cambias aplicable',
'tog-usenewrc'                => 'Aumenta cambias resente (JavaScript)',
'tog-numberheadings'          => 'Dona automatica numeros a titula',
'tog-showtoolbar'             => 'Mostra la bara de utiles per edita (JavaScript)',
'tog-editondblclick'          => 'Edita pajes a du clicas (JavaScript)',
'tog-editsection'             => 'Engrana la edita de sesion via lias de {edita}.',
'tog-editsectiononrightclick' => 'Engrana la edita de sesion par clica a la destra a titulos de sesion (JavaScript)',
'tog-showtoc'                 => 'Mostra la table de contenis (per pajes con plu ce tre titulos)',
'tog-rememberpassword'        => 'Memora me sinia per entra a esta computador (for a maximum of $1 {{PLURAL:$1|day|days}})',
'tog-watchcreations'          => 'Junta la pajes ce me ia creada a me lista de pajes oservada',
'tog-watchdefault'            => 'Junta pajes ce me ia edita a me lista de pajes oservada',
'tog-watchmoves'              => 'Junta pajes ce me ia moveda a me lista de pajes oservada',
'tog-watchdeletion'           => 'Junta pajes ce me ia sutrae a me lista de pajes oservada',
'tog-minordefault'            => 'Marca costumal tota editas como minor',
'tog-previewontop'            => 'Mostra la previde ante la caxa de editas',
'tog-previewonfirst'          => 'Mostra la previde a la edita prima',
'tog-nocache'                 => 'Desengana la reserva de pajes',
'tog-enotifwatchlistpages'    => 'Envia un eposta a me cuando un paje ce me oserva es cambiada',
'tog-enotifusertalkpages'     => 'Envia me un eposta cuando me paje de discutes es cambiada',
'tog-enotifminoredits'        => 'Ance envia un eposta a me con edita minor de pajes',
'tog-enotifrevealaddr'        => 'Descovre la me adirije de eposta en postas de nota',
'tog-shownumberswatching'     => 'Mostra la numero de usores oservante',
'tog-fancysig'                => 'Sinias simple (sin lia automatica)',
'tog-externaleditor'          => 'Usa costumal editadores esterna',
'tog-watchlisthideown'        => 'Asconde me editas de la lista de pajes oservada',
'tog-watchlisthidebots'       => 'Asconde editas par bot de la lista de pajes oservada',
'tog-watchlisthideminor'      => 'Asconde editas minor de la lista de pajes oservada',
'tog-ccmeonemails'            => 'Envia copias de la epostas ce me envia a otras a me ance',
'tog-showhiddencats'          => 'Mostra categorias ascondeda',

'underline-always'  => 'A tota tempo',
'underline-never'   => 'A no tempo',
'underline-default' => 'Surfador costumal',

# Dates
'sunday'        => 'soldi',
'monday'        => 'lundi',
'tuesday'       => 'martedi',
'wednesday'     => 'mercurdi',
'thursday'      => 'jovedi',
'friday'        => 'venerdi',
'saturday'      => 'saturdi',
'sun'           => 'Sol',
'mon'           => 'Lun',
'tue'           => 'Mar',
'wed'           => 'Mer',
'thu'           => 'Jov',
'fri'           => 'Ven',
'sat'           => 'Sat',
'january'       => 'janero',
'february'      => 'febrero',
'march'         => 'marto',
'april'         => 'april',
'may_long'      => 'maio',
'june'          => 'junio',
'july'          => 'julio',
'august'        => 'agosto',
'september'     => 'setembre',
'october'       => 'otobre',
'november'      => 'novembre',
'december'      => 'desembre',
'january-gen'   => 'Janero',
'february-gen'  => 'Febrero',
'march-gen'     => 'Marto',
'april-gen'     => 'April',
'may-gen'       => 'Maio',
'june-gen'      => 'Junio',
'july-gen'      => 'Julio',
'august-gen'    => 'Agosto',
'september-gen' => 'Setembre',
'october-gen'   => 'Otobre',
'november-gen'  => 'Novembre',
'december-gen'  => 'Desembre',
'jan'           => 'jan',
'feb'           => 'feb',
'mar'           => 'mar',
'apr'           => 'apr',
'may'           => 'mai',
'jun'           => 'jun',
'jul'           => 'jul',
'aug'           => 'ago',
'sep'           => 'set',
'oct'           => 'oto',
'nov'           => 'nov',
'dec'           => 'des',

# Categories related messages
'pagecategories'           => '{{PLURAL:$1|Categoria|Categorias}}',
'category_header'          => 'Articles en categoria "$1"',
'subcategories'            => 'Sucategorias',
'category-media-header'    => 'Medio en catagoria "$1"',
'category-empty'           => "''Aora, esta categoria no conteni pajes o medio.''",
'hidden-categories'        => '{{PLURAL:$1|Categoria|Categorias}} ascondeda',
'hidden-category-category' => 'Categorias ascondeda',
'listingcontinuesabbrev'   => 'cont.',

'about'         => 'Supra',
'article'       => 'Paje de contenis',
'newwindow'     => '(va abri en fenetra nova)',
'cancel'        => 'Cansela',
'moredotdotdot' => 'Plu...',
'mypage'        => 'Me paje',
'mytalk'        => 'Me discutes',
'anontalk'      => 'Discutes per esta IP',
'navigation'    => 'Naviga',
'and'           => '&#32;e',

# Cologne Blue skin
'qbfind'         => 'Trova',
'qbbrowse'       => 'Surfa',
'qbedit'         => 'Edita',
'qbpageoptions'  => 'Esta paje',
'qbpageinfo'     => 'Situa',
'qbmyoptions'    => 'Me pajes',
'qbspecialpages' => 'Pajes spesial',

'errorpagetitle'    => 'Era',
'returnto'          => 'Restora a $1.',
'tagline'           => 'De {{SITENAME}}',
'help'              => 'Disionario',
'search'            => 'Xerca',
'searchbutton'      => 'Xerca',
'go'                => 'Vade',
'searcharticle'     => 'Vade',
'history'           => 'Istoria de paje',
'history_short'     => 'Istoria',
'updatedmarker'     => 'renovida de me visita presedente',
'printableversion'  => 'Varia primable',
'permalink'         => 'Lia permanente',
'print'             => 'Primi',
'edit'              => 'Cambia',
'create'            => 'Crea',
'editthispage'      => 'Cambia esta paje',
'create-this-page'  => 'Crea esta paje',
'delete'            => 'Sutrae',
'deletethispage'    => 'Sutrae esta paje',
'undelete_short'    => 'Desutrae {{PLURAL:$1|edita|editas}}',
'protect'           => 'Proteje',
'protect_change'    => 'cambia',
'protectthispage'   => 'Proteje esta paje',
'unprotect'         => 'desproteje',
'unprotectthispage' => 'Desproteje esta paje',
'newpage'           => 'Paje nova',
'talkpage'          => 'Discute esta paje',
'talkpagelinktext'  => 'Parla',
'specialpage'       => 'Paje spesial',
'personaltools'     => 'Utiles personal',
'postcomment'       => 'Sesion nova',
'articlepage'       => 'Vide la paje de contenis',
'talk'              => 'Discutes',
'views'             => 'Vides',
'toolbox'           => 'Utiles',
'userpage'          => 'Vide paje de usor',
'projectpage'       => 'Vide la paje de projeta',
'imagepage'         => 'Vide paje de fix',
'mediawikipage'     => 'Vide la paje de mesaje',
'templatepage'      => 'Vide la paje de model',
'viewhelppage'      => 'vide la paje de aida',
'categorypage'      => 'Vide la paje de categoria',
'viewtalkpage'      => 'Vide la discute',
'otherlanguages'    => 'En otra linguas',
'redirectedfrom'    => '(Redirijeda de $1)',
'redirectpagesub'   => 'Redireta la paje',
'viewcount'         => 'Esta paje es asesada a $1 {{PLURAL:$1|ves|veses}}.',
'protectedpage'     => 'Paje protejeda',
'jumpto'            => 'Salta a:',
'jumptonavigation'  => 'naviga',
'jumptosearch'      => 'xerca',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Supra {{SITENAME}}',
'aboutpage'            => 'Project:Supra',
'copyrightpage'        => '{{ns:project}}:Diretos de autor',
'currentevents'        => 'Avenis presente',
'currentevents-url'    => 'Project:Avenis presente',
'disclaimers'          => 'Negas de respondablia',
'disclaimerpage'       => 'Project:Nega jeneral de respondablia',
'edithelp'             => 'Aida con edita',
'edithelppage'         => 'Help:Edita',
'helppage'             => 'Help:Contenis',
'mainpage'             => 'Paje Prima',
'mainpage-description' => 'Paje Prima',
'policy-url'           => 'Project:Politica',
'portal'               => 'Porta comunial',
'portal-url'           => 'Project:Porta comunial',
'privacy'              => 'Promete de privadia',
'privacypage'          => 'Project:Promete de privadia',

'ok'                      => 'Oce',
'retrievedfrom'           => 'Retraeda de "$1"',
'youhavenewmessages'      => 'Tu ave $1 ($2).',
'newmessageslink'         => 'mesajes nova',
'newmessagesdifflink'     => 'cambia presedente',
'youhavenewmessagesmulti' => 'Tu ave mesajes nova en $1',
'editsection'             => 'cambia',
'editold'                 => 'edita',
'viewsourceold'           => 'vide orijin',
'editlink'                => 'cambia',
'viewsourcelink'          => 'vide orijin',
'editsectionhint'         => 'Edita sesion: $1',
'toc'                     => 'Contenida',
'showtoc'                 => 'mostra',
'hidetoc'                 => 'asconde',
'viewdeleted'             => 'Vide $1?',
'feedlinks'               => 'Flue:',
'site-rss-feed'           => '$1 RSS Flue',
'site-atom-feed'          => '$1 Atom Flue',
'page-rss-feed'           => '"$1" RSS Flue',
'red-link-title'          => '$1 (paje no esiste)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Paje',
'nstab-user'      => 'Paje de usor',
'nstab-media'     => 'Paje de medio',
'nstab-special'   => 'Paje spesial',
'nstab-project'   => 'Paje de projeta',
'nstab-image'     => 'Fix',
'nstab-mediawiki' => 'Mesaje',
'nstab-template'  => 'Model',
'nstab-help'      => 'Paje de aida',
'nstab-category'  => 'Categoria',

# General errors
'error'               => 'Era',
'databaseerror'       => 'Era de base de datos',
'missingarticle-diff' => '(Difere: $1, $2)',
'internalerror'       => 'Era interna',
'internalerror_info'  => 'Era interna: $1',
'badtitle'            => 'Titulo es mal',
'badtitletext'        => 'La titulo de la paje tu ia desira ia es nonlegal, es vacua, o es un titulo intervici o interlingual no liada coreta. Es posable ce es un o plu simboles ce no pote es usada en titulos.',
'viewsource'          => 'Vide la orijin',
'viewsourcefor'       => 'per $1',
'viewsourcetext'      => 'Tu pote vide e copia la orijin de esta paje:',

# Login and logout pages
'yourname'                => 'Nom de usor:',
'yourpassword'            => 'Sinia de entra:',
'yourpasswordagain'       => 'Retape la sinia:',
'remembermypassword'      => 'Memora me sinia de entra a esta computador (for a maximum of $1 {{PLURAL:$1|day|days}})',
'yourdomainname'          => 'Tu domina:',
'login'                   => 'Identifia',
'nav-login-createaccount' => 'Sinia per entra',
'loginprompt'             => 'Tu debe engrana "tortetas" per entra {{SITENAME}}.',
'userlogin'               => 'Sinia per entra',
'logout'                  => 'Retira',
'userlogout'              => 'Sinia per retira',
'nologin'                 => "Tu no ave un conta? '''$1'''.",
'nologinlink'             => 'Crea  un conta',
'createaccount'           => 'Crea un conta',
'gotaccount'              => "Tu ave ja un conta? '''$1'''.",
'gotaccountlink'          => 'Sinia per entra',
'loginerror'              => 'Era de entra',
'loginsuccesstitle'       => 'Entra susedente',
'loginsuccess'            => "'''Tu ia entrada aora a {{SITENAME}} como \"\$1\".'''",
'nosuchuser'              => 'Es no usor con la nom "$1".
Esamina la spele, o [[Special:UserLogin/signup|crea un conta nova]].',
'nosuchusershort'         => 'Es no usor con esta nom "$1". Esamina la spele.',
'nouserspecified'         => 'Tu debe indica un nom de usor.',
'wrongpassword'           => 'La sinia de entra no es coreta. Per favore, atenta ancora.',
'wrongpasswordempty'      => 'La sinia de entra es vacua. Per favore, atenta ancora.',
'passwordtooshort'        => 'Tu sinia secreta no es legal o es tro corta.
El debe ave a min {{PLURAL:$1|1 simbol|$1 simboles}} e debe difere de tu nom de usor.',
'mailmypassword'          => 'Envia la sinia secreta nova par eposta',
'passwordremindertitle'   => 'Sinia secreta temporer nova per {{SITENAME}}',
'passwordremindertext'    => 'Algun (tu, probable, de adirije IP $1)
ia demanda ce nos envia a tu un sinia secreta nova per {{SITENAME}} ($4).
La sinia secreta per usor "$2" es aora "$3".
Tu debe sinia per entra e cambia tu sinia secreta aora.

Si algun otra ce tu ia envia esta demanda a nos, o si tu ia recorda tu sinia secreta e no vole cambia el aora, tu pote iniora esta mesaje e continua usa tu sinia secreta vea.',
'noemail'                 => 'No es un adirije de eposta per usor "$1".',
'passwordsent'            => 'Un sinia secreta ia es enviada a la adirije de eposta per "$1".
Per favore, sinia per entra ancora pos tu ia reseta el.',
'eauthentsent'            => 'Un eposta de serti ia es enviada a la adirije de eposta proposada.
Ante alga otra eposta es enviada a la conta, tu va nesesa segue la instruis en la eposta, per serti ce la conta es vera de tu.',
'emailconfirmlink'        => 'Aproba tu adirije de eposta',
'loginlanguagelabel'      => 'Lingua: $1',

# Change password dialog
'oldpassword'               => 'Sinia secreta vea:',
'newpassword'               => 'Sinia secreta nova:',
'retypenew'                 => 'Re-entra tu sinia secreta nova:',
'resetpass-submit-loggedin' => 'Cambia la sinia secreta',
'resetpass-temp-password'   => 'Sinia secreta tempora:',

# Edit page toolbar
'bold_sample'     => 'Testo en leteras forte',
'bold_tip'        => 'Testo en leteras forte',
'italic_sample'   => 'Testo en leteras italica',
'italic_tip'      => 'Testo en leteras italica',
'link_sample'     => 'Titulo de lia',
'link_tip'        => 'Lia interna',
'extlink_sample'  => 'http://www.example.com titulo de lia',
'extlink_tip'     => 'Lia esterna (recorda la prefis http://)',
'headline_sample' => 'Testo de titulo',
'headline_tip'    => 'Titulo de nivel 2',
'nowiki_sample'   => 'Introdui testo nonformida asi',
'nowiki_tip'      => 'Iniora la forma de la vici',
'image_tip'       => 'Fix interna',
'media_tip'       => 'Lia a fix',
'sig_tip'         => 'Tu sinia con la primi de la ora',
'hr_tip'          => 'Linia orizonal (usa nonfrecuente)',

# Edit pages
'summary'                    => 'Soma:',
'subject'                    => 'Sujeto/titulo:',
'minoredit'                  => 'Esta es un cambia minor',
'watchthis'                  => 'Oserva esta paje',
'savearticle'                => 'Fisa paje',
'preview'                    => 'Previde',
'showpreview'                => 'Mostra previde',
'showdiff'                   => 'Mostra diferes',
'anoneditwarning'            => "'''Avisa:''' Tu no ia sinia per entra.
Tu adirije de IP va es memorada en la istoria de revisas de esta paje.",
'summary-preview'            => 'Previde soma:',
'blockedtitle'               => 'Usor es impedida',
'blockedtext'                => "'''Tu nom de usor o adirije de IP ia es impedida.'''

La impedi ia es fada par $1.
La razon donada es ''$2''.

* Comensa de impedi: $8
* Fini de impedi: $6
* Ci algun intende impedi: $7

Tu pote contata $1 o un otra [[{{MediaWiki:Grouppage-sysop}}|dirijor]] per discute esta impedi.
Tu no pote usa la 'envia un eposta a esta usor' sin un adirije de eposta legal es indicada en tu
[[Special:Preferences|preferis de conta]] e tu no es impedida de usa el.
Tu adirije de IP es aora $3, e la identia de la impedi es #$5.
Per favore inclui tota esta detales en tu demandas.",
'newarticle'                 => '(Nova)',
'newarticletext'             => "Tu ia segue un lia a un paje ce no esista ja.
Per crea la paje, comensa scrive en la caxa a su
(vide la [[{{MediaWiki:Helppage}}|paje de aida]] per plu).
Si tu es asi par era, clica a la boton '''retro''' de tu surfador.",
'noarticletext'              => 'Es aora no testo a esta paje.
Tu pote [[Special:Search/{{PAGENAME}}|xerca per la titulo de esta paje]] en otra pajes,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} xerca la arcivos relatada],
o [{{fullurl:{{FULLPAGENAME}}|action=edit}} edita esta paje]</span>.',
'previewnote'                => "'''Esta sola un previde; cambias no es fisada ja'''",
'editing'                    => 'En la prosede de edita $1',
'editingsection'             => 'Edita $1 (sesion)',
'editingcomment'             => 'Edita $1 (sesion nova)',
'yourdiff'                   => 'Diferes',
'copyrightwarning'           => "Per favore nota ce tota labora a {{SITENAME}} es judida ce el es relasada su la $2 (vide $1 per detalias). Si tu no desira ce tu scrives ta es editada sin compati e redistribui sin tu permite, no sumita el asi!<br />
Tu ance promete a nos ce tu ia scriveda esta par tu mesma, o copiada esta de un domina publica o otra orijin libre.
'''NO SUMITA LABORA SU DIRETOS DE AUTOR SIN PERMITE!!'''",
'templatesused'              => '{{PLURAL:$1|Modele|Modeles}} usada en esta paje:',
'templatesusedpreview'       => '{{PLURAL:$1|Modele|Modeles}} usada en esta previde:',
'template-protected'         => '(protejeda)',
'template-semiprotected'     => '(proteje en parte)',
'nocreatetext'               => '{{SITENAME}} ave un restringe a la capas per crea pajes nova.
Tu pote vade a retro e edita un paje esistente, o  [[Special:UserLogin|sinia per entra o crea un conta]].',
'recreate-moveddeleted-warn' => "'''Avisa: Tu es recrea un paje ce ia es sutraed en la pasada.'''
Tu debe pensa ce es bon continua edita esta paje.
La arcivo de sutraes per esta paje es asi per conveni:",

# History pages
'viewpagelogs'           => 'Vide la arcivo de esta paje',
'currentrev'             => 'Cambia presente',
'currentrev-asof'        => 'Cambia presente a departi di $1',
'revisionasof'           => 'Revisa de $1',
'revision-info'          => 'Revisa de $1 par $2',
'previousrevision'       => '← Altera presedente',
'nextrevision'           => 'Revisa plu nova→',
'currentrevisionlink'    => 'Revisa presente',
'cur'                    => 'aora',
'next'                   => 'seguente',
'last'                   => 'dife',
'page_first'             => 'prima',
'page_last'              => 'final',
'histlegend'             => 'Diferente eleje: Marca la caxas de radio de esta varias per compare e clica entra o la boton a la funda.<br />
(presente) = difere de la varia presente,
(presedente) = difere con varia presedente, M = edita minor.',
'history-fieldset-title' => 'Surfa istoria',
'histfirst'              => 'Prima',
'histlast'               => 'Ultima',
'historysize'            => '({{PLURAL:$1|1 otuple|$1 otuples}})',
'historyempty'           => '(vacua)',

# Revision feed
'history-feed-title'          => 'Istoria de revises',
'history-feed-item-nocomment' => '$1 a $2',

# Revision deletion
'rev-delundel' => 'mostra/asconde',

# Diffs
'history-title'           => 'Istoria de cambias de "$1"',
'difference'              => '(Difere entre cambias)',
'lineno'                  => 'Linia $1:',
'compareselectedversions' => 'Compare varias elejeda',
'editundo'                => 'desfa',
'diff-multi'              => '({{PLURAL:$1|$1 revise|$1 revises}} medial no mostrada.)',

# Search results
'searchresults'             => 'Resultas de xerca',
'prevn'                     => '{{PLURAL:$1|$1}} presedente',
'nextn'                     => '{{PLURAL:$1|$1}} seguente',
'viewprevnext'              => 'Vide ($1 {{int:pipe-separator}} $2) ($3)',
'searchhelp-url'            => 'Help:Contenis',
'search-result-size'        => '$1 ({{PLURAL:$2|1 parola|$2 parolas}})',
'search-section'            => '(sesion $1)',
'search-interwiki-default'  => 'Resultas de $1:',
'search-interwiki-more'     => '(plu)',
'search-mwsuggest-enabled'  => 'con sujestes',
'search-mwsuggest-disabled' => 'zero sujestes',
'searchall'                 => 'tota',
'powersearch'               => 'Xerca avansada',

# Preferences page
'preferences'               => 'Preferis',
'mypreferences'             => 'Me preferis',
'skin-preview'              => 'Previde',
'saveprefs'                 => 'Fisa',
'rows'                      => 'Linias:',
'columns'                   => 'Colonas:',
'searchresultshead'         => 'Xerca',
'savedprefs'                => 'Tu preferis es fisada',
'timezoneregion-africa'     => 'Africa',
'timezoneregion-america'    => 'America',
'timezoneregion-antarctica' => 'Antartica',
'timezoneregion-arctic'     => 'Artica',
'timezoneregion-asia'       => 'Asia',
'timezoneregion-atlantic'   => 'Mar Atlantica',
'timezoneregion-australia'  => 'Australia',
'timezoneregion-europe'     => 'Europa',
'timezoneregion-indian'     => 'Mar Indian',
'timezoneregion-pacific'    => 'Mar Pasifica',
'prefs-files'               => 'Fixes',
'youremail'                 => 'Eposta:',
'username'                  => 'Nom de usor:',
'prefs-memberingroups'      => 'Membro de la {{PLURAL:$1|grupo|grupos}}:',
'yourrealname'              => 'Nom vera:',
'yourlanguage'              => 'Lingua:',
'yournick'                  => 'Suscrive:',
'yourgender'                => 'Seso:',
'gender-male'               => 'Mas',
'gender-female'             => 'Fema',
'email'                     => 'Eposta',
'prefs-help-realname'       => 'Tu nom vera no es obligada, ma si tu vole dona tu nom vera, el va es usada per onora tu per tu labora.',

# User rights
'userrights'     => 'Dirije de la diretos de usores',
'saveusergroups' => 'Fisa la grupo de usores',

# Groups
'group'       => 'Grupo:',
'group-user'  => 'Usores',
'group-sysop' => 'Dirijores',
'group-all'   => '(tota)',

'group-user-member' => 'Usor',

'grouppage-user'  => '{{ns:project}}:Usores',
'grouppage-sysop' => '{{ns:project}}:Dirijores',

# User rights log
'rightslog' => 'Catalogo de diretos de usor',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'edita esta paje',

# Recent changes
'nchanges'                       => '$1 {{PLURAL:$1|cambia|cambias}}',
'recentchanges'                  => 'Cambias resente',
'recentchangestext'              => 'Asi la lista de cambias resente en la vici.',
'recentchanges-feed-description' => 'Seque la cambias plu resente a la vici en esta flue.',
'rcnote'                         => 'Su es {{PLURAL:$1|cambia|cambias}} en la presedente {{PLURAL:$2|dia|dias}}, en $5, $4.',
'rcnotefrom'                     => "A su es la cambias de '''$2''' (asta '''$1''' es mostrada).",
'rclistfrom'                     => 'Mostra cambias nova, comensante de $1',
'rcshowhideminor'                => '$1 editas minor',
'rcshowhidebots'                 => '$1 botes',
'rcshowhideliu'                  => '$1 usores ativa aora',
'rcshowhideanons'                => '$1 usores sin nom',
'rcshowhidepatr'                 => '$1 editas patroliada',
'rcshowhidemine'                 => '$1 me editas',
'rclinks'                        => 'Mostra la $1 cambias presedente en la $2 dias presedente<br />$3',
'diff'                           => 'dife',
'hist'                           => 'isto',
'hide'                           => 'Asconde',
'show'                           => 'mostra',
'minoreditletter'                => 'm',
'newpageletter'                  => 'N',
'boteditletter'                  => 'b',
'rc_categories_any'              => 'Cualce',
'rc-enhanced-expand'             => 'Mostra detalias (JavaScript es nesesada)',
'rc-enhanced-hide'               => 'Asconde detalias',

# Recent changes linked
'recentchangeslinked'          => 'Cambias relateda',
'recentchangeslinked-feed'     => 'Cambias relateda',
'recentchangeslinked-toolbox'  => 'Cambias relateda',
'recentchangeslinked-title'    => 'Cambias relatada a "$1"',
'recentchangeslinked-noresult' => 'No cambias de pajes liada entre esta periodo.',
'recentchangeslinked-summary'  => "Esta lista conteni la cambias plu resente de la pajes liada a otra (o de la membros de un categoria).
Pajes a [[Special:Watchlist|tu lista de pajes oservada]] es en leteras '''forte'''.",
'recentchangeslinked-page'     => 'Nom de la paje:',

# Upload
'upload'        => 'Envia fixes',
'uploadbtn'     => 'Envia la fix',
'uploadlogpage' => 'Envia arcivo',
'savefile'      => 'Fisa fix',
'uploadedimage' => '"[[$1]]" es enviada',

'upload-file-error' => 'Era interna',

# Special:ListFiles
'imgfile'        => 'fix',
'listfiles'      => 'Lista de imajes',
'listfiles_name' => 'Nom',

# File description page
'file-anchor-link'          => 'Fix',
'filehist'                  => 'Istoria de fix',
'filehist-help'             => 'Clica a un data/tempo per vide la fix como el ia aperi alora.',
'filehist-current'          => 'aora',
'filehist-datetime'         => 'Date/Tempo',
'filehist-user'             => 'Usor',
'filehist-dimensions'       => 'Mesuras',
'filehist-filesize'         => 'Grandia de fix',
'filehist-comment'          => 'Comenta',
'imagelinks'                => 'Lias de fix',
'linkstoimage'              => 'Esta {{PLURAL:$1|paje|pajes}} lia a esta fix:',
'nolinkstoimage'            => 'Es no pajes ce lia a esta fix.',
'sharedupload'              => 'Esta fix es parte de $1 e pote es usada par otra projetas.',
'uploadnewversion-linktext' => 'Envia un varia nova de esta fix',

# MIME search
'mimesearch' => 'Xerca de MIME',

# List redirects
'listredirects' => 'Lista redirijes',

# Unused templates
'unusedtemplates' => 'modeles no usada',

# Random page
'randompage' => 'Paje acaso',

# Random redirect
'randomredirect' => 'Redirije acaso',

# Statistics
'statistics' => 'Statisticas',

'disambiguations' => 'Pajes desambiguinte',

'doubleredirects' => 'Redirijes duple',

'brokenredirects' => 'Redirijes rompeda',

'withoutinterwiki' => 'Pajes sin lias de lingua',

'fewestrevisions' => 'Pajes con la min revides',

# Miscellaneous special pages
'nbytes'                  => '$1 {{PLURAL:$1|oteta|otetas}}',
'nlinks'                  => '$1 {{PLURAL:$1|lia|lias}}',
'nmembers'                => '$1 {{PLURAL:$1|membro|membros}}',
'lonelypages'             => 'Pajes orfanida',
'uncategorizedpages'      => 'Pajes sin categoria',
'uncategorizedcategories' => 'Categorias sin categoria',
'uncategorizedimages'     => 'Fixes sin categoria',
'uncategorizedtemplates'  => 'Modeles sin categoria',
'unusedcategories'        => 'Categorias nonusada',
'unusedimages'            => 'Images nonusada',
'popularpages'            => 'Pajes poplal',
'wantedcategories'        => 'Categorias desireda',
'wantedpages'             => 'Pajes desirada',
'mostlinked'              => 'Pajes la plu liada',
'mostlinkedcategories'    => 'Categorias a ce es la plu lias',
'mostlinkedtemplates'     => 'Modeles a ce es la plu lias',
'mostcategories'          => 'Pajes con la plu categorias',
'mostimages'              => 'Fixes a ce es la plu lias',
'mostrevisions'           => 'Pajes con la plu revisas',
'prefixindex'             => 'Tota pajes con prefisa',
'shortpages'              => 'Pajes corta',
'longpages'               => 'Pajes longa',
'deadendpages'            => 'Pajes sin sorti',
'protectedpages'          => 'Pajes protejeda',
'listusers'               => 'Lista de usores',
'newpages'                => 'Pajes nova',
'ancientpages'            => 'Pajes la plu vea',
'move'                    => 'Move',
'movethispage'            => 'Move esta paje',
'unusedimagestext'        => '<p>Nota ce otra locas de rede pote lia a un imaje con un URL direta, e donce el pote continua es listada asi contra ce el es usada ativa.</p>',
'unusedcategoriestext'    => 'La categorias seguente esiste sin es usada par otra articles o categorias.',
'pager-newer-n'           => '{{PLURAL:$1|1 plu resente|$1 plu resentes}}',
'pager-older-n'           => '{{PLURAL:$1|1 plu vea|$1 plu veas}}',

# Book sources
'booksources'    => 'Orijines de libros',
'booksources-go' => 'Vade',

# Special:Log
'specialloguserlabel'  => 'Usor:',
'speciallogtitlelabel' => 'Titulo:',
'log'                  => 'Lista de atas',
'all-logs-page'        => 'Tota catalogos',

# Special:AllPages
'allpages'       => 'Tota pajes',
'alphaindexline' => '$1 a $2',
'nextpage'       => 'Paje seguente ($1)',
'prevpage'       => 'Paje presedente ($1)',
'allpagesfrom'   => 'Mostra pajes comensante a:',
'allarticles'    => 'Tota pajes',
'allpagesprev'   => 'Presedente',
'allpagesnext'   => 'Seguente',
'allpagessubmit' => 'Vade',
'allpagesprefix' => 'Mostra pajes con prefis:',

# Special:Categories
'categories'         => 'Categorias',
'categoriespagetext' => 'Es la categorias seguente en la vici.
[[Special:UnusedCategories|Unused categories]] are not shown here.
Also see [[Special:WantedCategories|wanted categories]].',

# Special:LinkSearch
'linksearch-ok' => 'Xerca',

# Special:ListGroupRights
'listgrouprights-group'   => 'Grupo',
'listgrouprights-members' => '(lista de membros)',

# E-mail user
'emailuser' => 'Envia un eposta a esta usor',
'emailfrom' => 'De',
'emailto'   => 'Per',

# Watchlist
'watchlist'         => 'Pajes oservada',
'mywatchlist'       => 'Me lista de pajes oservada',
'nowatchlist'       => 'Tu ave no cosas en tu lista oservada',
'addedwatchtext'    => "La paje \"[[:\$1]]\" ia es juntada a tu [[Special:Watchlist|lista de pajes oservada]].
Cambias future a esta paje e se paje de discutes va es listada ala, e la paje va apera en leteras '''forte''' en la [[Special:RecentChanges|lista de cambias resente]] per es plu fasil oservada.

Si tu vole sutrae la paje de tu lista de pajes oservada en la futur, clica a \"no oserva\" en la bara a la lado.",
'removedwatchtext'  => 'La paje "[[:$1]]" ia es sutraeda de [[Special:Watchlist|tu lista de pajes oservada]].',
'watch'             => 'Oserva',
'watchthispage'     => 'Oserva esta paje',
'unwatch'           => 'Nonoserva',
'watchlist-details' => '{{PLURAL:$1|$1 paje|$1 pajes}} osservada, sin pajes de discutes.',
'watchlistcontains' => 'Tu lista oservada teni $1 {{PLURAL:$1|paje|pajes}}.',
'wlshowlast'        => 'Mostra la $1 oras e $2 dias presedente $3',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Oserva...',
'unwatching' => 'No oserva...',

'enotif_newpagetext' => 'Esta es un paje nova',
'created'            => 'Creada',

# Delete
'deletepage'            => 'Sutrae la paje',
'confirm'               => 'Aproba',
'historywarning'        => 'Avisa! La paje ce tu intende sutrae, el ave un istoria:',
'confirmdeletetext'     => 'Tu va pronto sutrae un paje con tota se istoria. Per favore, afirma ce tu intende esta, ce tu comprende la resultas, e ce tu fa esta en acorda con [[{{MediaWiki:Policy-url}}|la prometes]].',
'actioncomplete'        => 'Ata completada',
'deletedtext'           => '"$1" ia es sutraeda.
Vide $2 per un catalogo de sutraes resente.',
'deletedarticle'        => 'sutraeda "[[$1]]"',
'dellogpage'            => 'catalogo de sutraes',
'deletecomment'         => 'Razona:',
'deleteotherreason'     => 'Otra/plu razona:',
'deletereasonotherlist' => 'Otra razona',

# Rollback
'rollbacklink' => 'retro',

# Protect
'protectlogpage'              => 'Catalogo de protejes',
'protectedarticle'            => '"[[$1]]" protejeda',
'unprotectedarticle'          => "''[[$1]]'' desprotejeda",
'protect-title'               => 'Fisa nivel de proteje a "$1"',
'prot_1movedto2'              => '[[$1]] es moveda a [[$2]]',
'protect-legend'              => 'Aproba la proteje',
'protectcomment'              => 'Razona:',
'protectexpiry'               => 'Fini:',
'protect_expiry_invalid'      => 'Ora de fini no es legal.',
'protect_expiry_old'          => 'Ora de fini es en la pasada.',
'protect-text'                => "Tu pote vide e cambia la nivel de proteje asi per la paje '''$1'''.",
'protect-locked-access'       => "Tu conta no ave permite per cambia niveles de proteje.
Asi es la ajustas presente per la paje '''$1''':",
'protect-cascadeon'           => 'Esta paje es aora protejeda per ce el es incluida en esta {{PLURAL:$1|paje|pajes}} ce ave proteje cascadente ativa. Tu pote cambia la nivel de proteje per esta paje, ma esta no va influense la proteje cascadente.',
'protect-default'             => 'Permete tota usores',
'protect-fallback'            => 'Nesesa permite "$1"',
'protect-level-autoconfirmed' => 'Impedi usores nova e nonenscriveda',
'protect-level-sysop'         => 'Sola sysopes',
'protect-summary-cascade'     => 'cascadente',
'protect-expiring'            => 'fini $1 (UTC)',
'protect-cascade'             => 'Proteje pajes ce es incluida en esta paje (proteje cascadente)',
'protect-cantedit'            => 'Tu no pote cambia la nivel de proteje de esta paje, per ce tu no ave la permite per edita el.',
'protect-expiry-options'      => '1 ora:1 hour,1 dia:1 day,1 semana:1 week,2 semanas:2 weeks,1 mensa:1 month,3 mensas:3 months,6 mensas:6 months,1 anio:1 year,nonlimitada:infinite',
'restriction-type'            => 'Permete:',
'restriction-level'           => 'Nivel de restrinje:',

# Undelete
'undelete'               => 'Restora paje sutraeda',
'undeletebtn'            => 'Restora',
'undelete-search-submit' => 'Xerca',

# Namespace form on various pages
'namespace'      => 'Loca de nom:',
'invert'         => 'Reversa la eleje',
'blanknamespace' => '(Prima)',

# Contributions
'contributions' => 'Contribuis de usor',
'mycontris'     => 'Me contribuis',
'contribsub2'   => 'Per $1 ($2)',
'uctop'         => '(culmine)',
'month'         => 'De mensa (e plu vea):',
'year'          => 'De anio (e plu vea):',

'sp-contributions-newbies'     => 'Sola mostra contribuis de contas nova',
'sp-contributions-newbies-sub' => 'Per contas nova',
'sp-contributions-blocklog'    => 'Impedi arcivo',
'sp-contributions-talk'        => 'Parla',
'sp-contributions-userrights'  => 'Dirije de la diretos de usores',
'sp-contributions-search'      => 'Xerca per contribuis',
'sp-contributions-username'    => 'Adirije de IP o nom de usor:',
'sp-contributions-submit'      => 'Xerca',

# What links here
'whatlinkshere'            => 'Ce es liada a asi',
'whatlinkshere-title'      => 'Pajes ci lia a "$1"',
'whatlinkshere-page'       => 'Paje:',
'linkshere'                => "Esta pajes lia a '''[[:$1]]''':",
'nolinkshere'              => "No pajes lia a '''[[:$1]]'''.",
'isredirect'               => 'redirije paje',
'istemplate'               => 'inclui',
'isimage'                  => 'lia de imaje',
'whatlinkshere-prev'       => '{{PLURAL:$1|presesdente|$1 presedente}}',
'whatlinkshere-next'       => '{{PLURAL:$1|seguente|$1 seguente}}',
'whatlinkshere-links'      => '← lias',
'whatlinkshere-hideredirs' => '$1 redirijes',
'whatlinkshere-hidelinks'  => '$1 lias',
'whatlinkshere-filters'    => 'Filtros',

# Block/unblock
'blockip'            => 'Impedi usor',
'ipbreason'          => 'Razona:',
'ipbsubmit'          => 'Impedi esta usor',
'ipboptions'         => '2 oras:2 hours,1 dia:1 day,3 dias:3 days,1 semana:1 week,2 semanas:2 weeks,1 mensa:1 month,3 mensas:3 months,6 mensas:6 months,1 anio:1 year,nonlimitada:infinite',
'blockipsuccesssub'  => 'La impedi susede',
'ipusubmit'          => 'Desimpedi esta adirije',
'ipblocklist'        => 'Liste de adirijes de IP e usores impedida',
'ipblocklist-submit' => 'Xerca',
'blocklink'          => 'impedi',
'unblocklink'        => 'desimpedi',
'contribslink'       => 'contribuis',
'blocklogpage'       => 'impedi arcivo',
'blocklogentry'      => 'impedida [[$1]] con un tempo de fini de $2 $3',

# Move page
'move-page-legend' => 'Move paje',
'movepagetext'     => "Usa la forma a su va cambia la nom de un paje, e va move tota se istoria a la nom nova.
La titulo vea va deveni un paje de redirije a la titulo nova.
Lias a la titulo de la paje vea no va es cambiada;
Tu debe vide serta ce es redirijes duple o rompeda.
Tu es respondable per es serta ce la lias va continua vade a la locas intendeda.

Nota ce la paje '''no''' va es moveda si es ja un paje a la titulo nova, sin el es vacua o un redirije e no ave un istoria de editas presedente.
Esta sinifia ce tu pote cambia la nom de un paje a la loca presedente si tu era, e tu no pote scrive supra un paje ce esiste ja.

'''AVISA!'''
Esta pote es un cambia dramos e nonespetada per un paje poplal;
per favore, es serta ce tu comprende la resulta de esta ata ante tu continua.",
'movepagetalktext' => "La paje de discuta de esta paje va es moveda automatica con el '''eseta si:'''
*Un paje de discuta ce no es vacua esiste ja su la nom nova, o
*Tu cambia la indica en la caxa su.

En esta casos, tu va nesesa move o fusa la paje per mano, si desirada.",
'movearticle'      => 'Move paje:',
'newtitle'         => 'A titulo nova:',
'move-watch'       => 'Oserva esta paje',
'movepagebtn'      => 'Move paje',
'pagemovedsub'     => 'La move ia susede',
'movepage-moved'   => '\'\'\'"$1" ia es moveda a "$2"\'\'\'',
'articleexists'    => 'Un paje con acel nom esiste ja, o la nom ce tu ia eleje no es un nom legal. Per favore, eleje un otra nom.',
'talkexists'       => "'''La paje se mesma ia es moveda, ma la paje de discutes no pote es moveda, per ce un esiste ja a la titulo nova. Per favore, fusa los per mano'''",
'movedto'          => 'moveda a',
'movetalk'         => 'Move la paje de discutes ance',
'1movedto2'        => '[[$1]] es moveda a [[$2]]',
'1movedto2_redir'  => '[[$1]] es moveda a [[$2]] tra redirije',
'movelogpage'      => 'Move arcive',
'movelogpagetext'  => 'A su es un lista de pajes moveda',
'movereason'       => 'Razona:',
'revertmove'       => 'retro',

# Export
'export' => 'Esporta pajes',

# Namespace 8 related
'allmessages' => 'Notas de sistem',

# Thumbnails
'thumbnail-more'  => 'Grandi',
'thumbnail_error' => 'Era en crea la imajeta: $1',

# Special:Import
'import' => 'Emporta pajes',

# Import log
'importlogpage' => 'Importa arcivo',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Tu paje de usor',
'tooltip-pt-mytalk'               => 'Tu paje de discutes',
'tooltip-pt-preferences'          => 'Me preferis',
'tooltip-pt-watchlist'            => 'La lista de pajes ce tu oserva per cambias',
'tooltip-pt-mycontris'            => 'Lista de tu contribuis',
'tooltip-pt-login'                => 'Nos preferi si tu sinia per entra, ma tu es no obligada.',
'tooltip-pt-logout'               => 'Sinia per retira',
'tooltip-ca-talk'                 => 'Discute de la paje de contenis',
'tooltip-ca-edit'                 => 'Tu pote edita esta paje. Per favore, usa la boton de previde ante fisa.',
'tooltip-ca-addsection'           => 'Inisia un sesion nova',
'tooltip-ca-viewsource'           => 'Esta paje es protejeda. Tu pote vide se orijin.',
'tooltip-ca-protect'              => 'Proteje esta paje',
'tooltip-ca-delete'               => 'Sutrae esta paje',
'tooltip-ca-move'                 => 'Move esta paje',
'tooltip-ca-watch'                => 'Junta esta paje a tu lista de pajes oservada',
'tooltip-ca-unwatch'              => 'Sutrae esta paje de tu lista de pajes oservada',
'tooltip-search'                  => 'Xerca {{SITENAME}}',
'tooltip-p-logo'                  => 'Visita la paje prima',
'tooltip-n-mainpage'              => 'Visita la paje prima',
'tooltip-n-mainpage-description'  => 'Visita la paje prima',
'tooltip-n-portal'                => 'De la projeta, ce tu pote fa, do tu pote trova cosas',
'tooltip-n-currentevents'         => 'Trova informa presedente de avenis nova',
'tooltip-n-recentchanges'         => 'La lista de cambias resente en la vici.',
'tooltip-n-randompage'            => 'Carga un paje acaso',
'tooltip-n-help'                  => 'La loca per descovre.',
'tooltip-t-whatlinkshere'         => 'Lista de tota pajes de vici ce lia a asi',
'tooltip-t-contributions'         => 'Vide la lista de contribuis de esta usor',
'tooltip-t-emailuser'             => 'Envia un eposta a esta usor',
'tooltip-t-upload'                => 'Envia fixes',
'tooltip-t-specialpages'          => 'Lista de tota pajes spesial',
'tooltip-ca-nstab-user'           => 'Vide la paje de usor',
'tooltip-ca-nstab-project'        => 'Vide la paje de la projeta',
'tooltip-ca-nstab-image'          => 'Vide la paje de fix',
'tooltip-ca-nstab-template'       => 'Mostra la model',
'tooltip-ca-nstab-help'           => 'Vide la paje de aida',
'tooltip-ca-nstab-category'       => 'Vide la paje de la categoria',
'tooltip-minoredit'               => 'Indica ce esta es un edita minor',
'tooltip-save'                    => 'Fisa tu cambias',
'tooltip-preview'                 => 'Previde tu cambias; per favore usa esta ante fisa!',
'tooltip-diff'                    => 'Mostra tu cambias de la testo.',
'tooltip-compareselectedversions' => 'Vide la diferes entre la du varias elejeda de esta paje.',
'tooltip-watch'                   => 'Junta esta paje a tu lista de pajes oservada',

# Attribution
'others' => 'otras',

# Browsing diffs
'previousdiff' => '← Difere plu vea',
'nextdiff'     => 'Difere plu nova →',

# Media information
'widthheightpage' => '$1×$2, $3 {{PLURAL:$3|paje|pajes}}',
'file-info-size'  => '$1 × $2 pixel, grandia de fix: $3, MIME tipo: $4',
'file-nohires'    => '<small>No plu densia posable.</small>',
'svg-long-desc'   => 'SVG fix, per nom $1 × $2 pixeles, grandia de fix: $3',
'show-big-image'  => 'Densia masima',

# Special:NewFiles
'newimages' => 'Imajes nova',
'ilsubmit'  => 'Xerca',

# Bad image list
'bad_image_list' => 'La forma es la seguente:

Sola linias de un lista (ce comensa con *) es considerada.
La lia prima a la linia nesesa es un lia a un mal fix.
Cada lias seguente a la mesma linia es considerada es esetas, ce es, la pajes do la fix pote aveni enlinia.',

# Metadata
'metadata'          => 'Metadata',
'metadata-help'     => 'Esta fix conteni plu informa, posable juntada de un camera dijital o un scanador usada per crea o dijiti el.
Si la fix ia es cambiada de se stato orijinal, alga detalias pote no es clara en la fix cambiada.',
'metadata-expand'   => 'Mostra detalias estendente',
'metadata-collapse' => 'Asconde detalias estendeda',
'metadata-fields'   => 'Campos de EXIF metadata listada en esta mesaje va es inclui cuando la table de metadata es minimida.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# EXIF tags
'exif-exposuretime-format' => '$1 sec. ($2)',

# External editor support
'edit-externally'      => 'Edita esta fix con un programa esterna',
'edit-externally-help' => '(Vide la [//www.mediawiki.org/wiki/Manual:External_editors instruis per comensa] per plu instruis)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'tota',
'namespacesall' => 'tota',
'monthsall'     => 'tota',

# action=purge
'confirm_purge_button' => 'Oce',

# Watchlist editing tools
'watchlisttools-view' => 'Vide cambias pertinente',
'watchlisttools-edit' => 'Vide e edita la lista de pajes oservada',
'watchlisttools-raw'  => 'Edita la lista rua de pajes oservada',

# Special:Version
'version'         => 'Varia',
'version-version' => '(Varia $1)',

# Special:FilePath
'filepath-page' => 'Fix:',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Xerca',

# Special:SpecialPages
'specialpages' => 'Pajes spesial',

);
